"""
A collection of reusable and extendable input and form 
classes.
"""

from django.forms import DateInput, DateTimeInput, Form, CharField
from django.utils.translation import gettext_lazy as _


class CustomDateInput(DateInput):
    """
    This subclass of `DateInput` provides the HTML input type "date" for widgets.
    """
    input_type = 'date'

    def format_value(self, value):
        return value


class CustomDateTimeInput(DateTimeInput):
    """
    This subclass of `DateTimeInput` provides the HTML input type "datetime-local" 
    for widgets.
    """
    input_type = 'datetime-local'

    def format_value(self, value):
        return value


class FilterForm(Form):
    """
    A generic form used for simple text based queries.
    """
    query = CharField(
        label=_('Query'),
        max_length=255,
        required=False,
        strip=True
    )
