"""
A collection of reusable and extendable mixin classes.
"""

from django.core.exceptions import ImproperlyConfigured
from django.urls import reverse


class OnSuccessMixin():
    """
    A simple mixin providing some functionality for redirecting after an successful action.
    """
    on_success = None
    drop_key = None
    kwarg_override = None

    def get_success_url(self):
        """
        Return the URL meant for redirecting after a successful action.
        """
        if not self.on_success:
            raise ImproperlyConfigured(
                "No name to redirect to. Provide a on_success.")

        match = self.request.resolver_match
        kwargs = match.kwargs
        if self.kwarg_override is not None:
            kwargs.update(self.kwarg_override)
        namespaces = match.namespaces

        if self.drop_key is not None and self.drop_key in kwargs:
            del kwargs[self.drop_key]

        return reverse(
            ':'.join(namespaces + [self.on_success]),
            kwargs=kwargs,
        )
