const query_field = document.getElementById("id_query");
query_field.setAttribute('list', "suggestions");

const datalist = document.createElement("datalist");
datalist.setAttribute('id', "suggestions");
query_field.after(datalist);

function debounce(func, timeout = 300) {
    let timer;
    return (...args) => {
      clearTimeout(timer);
      timer = setTimeout(() => { func.apply(this, args); }, timeout);
    };
}

async function options(event) {
    const url = window.location.pathname;
    const suche = event.target.value
        .trim()
        .replace(/[^a-z0-9@+.:\- ]/gi, '');
    let already_option = false;
    for (let option of datalist.getElementsByTagName("option"))
        already_option |= option.value === suche;    
    if ( !already_option ) {
        datalist.innerHTML = "";
        try {
            const response = await fetch(
                `${url}?query_field=${suche.replace(/\s/g, '+')}`,
                {
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    method: 'GET',
                }
            ); 
            const suggestions = (await response.json())['suggestions'];
            for(let suggestion in suggestions) {
                const option = document.createElement("option");
                option.setAttribute('value', suggestions[suggestion]);
                datalist.appendChild(option);
            }
        } catch (error) {
            console.log(error);
        }
    }
}

query_field.addEventListener('input', debounce(options));
