"""
This submodule contains the routing for this module.
"""
from django.urls import path, reverse_lazy
from django.utils.translation import gettext_lazy as _
from django.contrib.auth.views import (
    LoginView, LogoutView, PasswordChangeView, PasswordChangeDoneView,
    PasswordResetView, PasswordResetDoneView, PasswordResetConfirmView,
    PasswordResetCompleteView,
)
from django.views.generic import TemplateView
from .views import *

app_name = 'users'
urlpatterns = [
    path(
        _('login/'),
        LoginView.as_view(redirect_authenticated_user=True),
        name='login'
    ),
    path(_('logout/'), LogoutView.as_view(), name='logout'),
    path(
        _('password_change/'),
        PasswordChangeView.as_view(
            success_url=reverse_lazy('vkk:users:password_change_done')
        ),
        name='password_change'
    ),
    path(
        _('password_change/done/'),
        PasswordChangeDoneView.as_view(),
        name='password_change_done'
    ),
    path(
        _('user_details_change/'),
        UserDetailsChangeView.as_view(
            success_url=reverse_lazy('vkk:users:user_details_change_done')
        ),
        name='user_details_change'
    ),
    path(
        _('user_details_change/done/'),
        UserDetailsChangeSuccessView.as_view(),
        name='user_details_change_done'
    ),
    path(
        _('password_reset/'),
        PasswordResetView.as_view(
            success_url=reverse_lazy('vkk:users:password_reset_done')
        ),
        name='password_reset'
    ),
    path(
        _('password_reset/done/'),
        PasswordResetDoneView.as_view(),
        name='password_reset_done'
    ),
    path(
        _('reset/<uidb64>/<token>/'),
        PasswordResetConfirmView.as_view(
            success_url=reverse_lazy('vkk:users:password_reset_complete')
        ),
        name='password_reset_confirm'
    ),
    path(
        _('reset/done/'),
        PasswordResetCompleteView.as_view(),
        name='password_reset_complete'
    ),
    path(
        'registration_confirm/<token>/<signature>/',
        RegistrationConfirmView.as_view(),
        name='registration_confirm'
    ),
    path(
        _('registration_confirm/invalid_link/'),
        TemplateView.as_view(
            template_name='vkk/users/invalid_registration.html'),
        name='invalid_registration'
    ),
    path(
        _('registration_confirm/done/'),
        TemplateView.as_view(
            template_name='vkk/users/registration_confirm_done.html'),
        name='registration_confirm_done',
    ),
]
