"""
This submodule contains the routing configuration.
"""

from django.urls import path, include
from django.utils.translation import gettext_lazy as _
from vkk.models import SalaryLevelDate
from vkk.workhours.accounting.views import (
    AccountingCreateView, AccountingUpdateView,
    AccountingDeleteView, AccountingListView,
    AccountingSuccessView
)
from ..forms import SalaryLevelCostForm

model = {'model': SalaryLevelDate}

app_name = 'salary_levels'
urlpatterns = [
    path(
        _('create/'),
        AccountingCreateView.as_view(
            form_class=SalaryLevelCostForm,
            **model
        ),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:pk>/update/'),
        AccountingUpdateView.as_view(
            form_class=SalaryLevelCostForm,
            **model
        ),
        name='update'
    ),
    path(
        _('update/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/update_success.html',
            **model
        ),
        name='update_success'
    ),
    path(
        _('<int:pk>/delete/'),
        AccountingDeleteView.as_view(**model),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model
        ),
        name='delete_success'
    ),
    path(
        '',
        AccountingListView.as_view(
            **model,
            fields=['date'],
            ordering=['date'],
        ),
        name='default'
    ),
]