"""
This submodule contains the routing configuration.
"""

from django.urls import path
from django.utils.translation import gettext_lazy as _
from ..views import *
from vkk.workhours.models import Department
from .views import EvaluationView

model = {'model': Department}
fields = {'fields': ['accounting_entry', 'name', 'invoice_number']}
action_options = {
    'action_options': {
        'update': _('Update'),
        'delete': _('Delete'),
        'evaluation': _('Evaluation'),
    }
}

app_name = 'departments'
urlpatterns = [
    path(
        _('create/'),
        AccountingCreateView.as_view(**model, **fields),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:pk>/update/'),
        AccountingUpdateView.as_view(**model, **fields),
        name='update'
    ),
    path(
        _('update/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/update_success.html',
            **model
        ),
        name='update_success'
    ),
    path(
        _('<int:pk>/delete/'),
        AccountingDeleteView.as_view(**model),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model
        ),
        name='delete_success'
    ),
    path(
        '',
        AccountingFilterView.as_view(
            **model,
            **fields,
            ordering=['name'],
            **action_options,
        ),
        name='default'
    ),
    path(
        _('<int:pk>/evaluation/'),
        EvaluationView.as_view(),
        name='evaluation'
    )
]
