"""
This submodule contains class based views.
"""

from smtplib import SMTPException
from django.urls import reverse_lazy, reverse
from django.http import HttpResponseRedirect
from django.views.generic import FormView, TemplateView
from vkk.workhours.accounting.mixins import AccountantRequiredMixin
from .forms import MailingListForm

class MailingListView(AccountantRequiredMixin, FormView):
    """
    A class based `View` providing the utilities to send out email to a mailing list.
    """
    form_class = MailingListForm
    success_url = reverse_lazy('vkk:workhours:accounting:mailing_list:success')
    template_name = 'vkk/workhours/accounting/mailing_list/form.html'

    def form_valid(self, form):
        try:
            form.send_mail()
        except SMTPException:
            return HttpResponseRedirect(
                reverse('vkk:workhours:accounting:mailing_list:failed')
            )
        return super().form_valid(form)

class MailingListSuccessView(AccountantRequiredMixin, TemplateView):
    """
    A class based `View` providing the utilities to indicate the successful delivery
    of email to a mailing list.
    """
    template_name = 'vkk/workhours/accounting/mailing_list/success.html'

class MailingListFailedView(AccountantRequiredMixin, TemplateView):
    """
    A class based `View` providing the utilities to indicate the failure to 
    send out email to a mailing list.
    """
    template_name = 'vkk/workhours/accounting/mailing_list/failed.html'
