"""
This submodule contains some mixin classes used through all other submodules.
"""

from django.contrib.auth.mixins import AccessMixin

class AccountantRequiredMixin(AccessMixin):
    """
    A mixin class for checking whether the current user has accounting permissions.
    """
    def dispatch(self, request, *args, **kwargs):
        if (not request.user.is_authenticated or
        not request.user.is_accountant):
            return self.handle_no_permission()
        return super().dispatch(request, *args, **kwargs)