"""
A collection of forms used in this module.
"""

from django.forms import ModelForm
from datetime import date, timedelta
from vkk.generic.forms import CustomDateInput
from vkk.users.models import NewUser, send_renew_mail

class NewUserRenewForm(ModelForm):
    """
    A class based `View` providing functionality for extending the expiration date for a
    user to register.
    """
    class Meta:
        model = NewUser
        fields = ['expiration_date']
        widgets = {'expiration_date' : CustomDateInput}
    
    def __init__(self, *args, **kwargs):
        """
        Creates and returns a new object of this class.
        """
        if ( kwargs.get('initial') is None 
            or kwargs['initial'].get('expiration_date') is None ):
            kwargs['initial'] = {
                'expiration_date' : date.today() + timedelta(days=21)
            }
        super().__init__(*args, **kwargs)

    def save(self, commit=True):
        """
        Saves and returns a `NewUser` associated with this `Form` class object.
        """
        send_renew_mail(self.instance)
        return super().save(commit)
