"""
This submodule contains the routing configuration.
"""

from django.urls import path
from django.utils.translation import gettext_lazy as _
from vkk.workhours.accounting.views import AccountingFilterView, AccountingSuccessView, AccountingUpdateView
from vkk.users.models import NewUser
from .forms import NewUserRenewForm

model = {'model': NewUser}

app_name = 'new_users'
urlpatterns = [
    path(
        _('<int:pk>/renew/'),
        AccountingUpdateView.as_view(
            on_success='renew_success',
            form_class=NewUserRenewForm,
            **model
        ),
        name='renew'
    ),
    path(
        _('renew/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/update_success.html',
            **model
        ),
        name='renew_success'
    ),
    path(
        '',
        AccountingFilterView.as_view(
            **model,
            fields=['user__first_name', 'user__last_name', 'user__email', 'expiration_date'],
            template_name='vkk/workhours/accounting/new_users/filter.html',
            ordering=['user__last_name', 'user__first_name']
        ),
        name='default',
    ),
]
