"""
This submodule contains class based views.
"""

from vkk.workhours.accounting.views import (
    AccountingCreateView, AccountingListView
)
from vkk.workhours.models import ProjectFundedStaffDate, ProjectFundedStaff
from .forms import ProjectFundedStaffForm

class ProjectFundedStaffListView(AccountingListView):
    """
    A class based `View` providing utilities for listing `ProjectFundedStaff`.
    """
    model = ProjectFundedStaffDate
    fields = ['date']
    ordering = ['date']

    def get_queryset(self):
        """
        Returns a query set of `ProjectFundedStaffDate` for the given project.
        """
        return super().get_queryset().filter(
            project__invoice_number=self.kwargs['invoice_number'],
        )

class ProjectFundedStaffCreateView(AccountingCreateView):
    """
    A class based `View` providing utilities for creating `ProjectFundedStaff`.
    """
    model = ProjectFundedStaffDate
    form_class = ProjectFundedStaffForm

    def get_form_kwargs(self):
        """
        Returns a dictionary of keyword arguments used for instanciating the associated form.
        """
        kwargs = super().get_form_kwargs()
        kwargs.update({
            'invoice_number' : self.kwargs['invoice_number'],
        })
        return kwargs
