"""
This submodule contains the routing configuration.
"""

from django.urls import include, path
from django.utils.translation import gettext_lazy as _
from vkk.models import Receipt
from vkk.workhours.accounting.views import (
    AccountingSuccessView, AccountingDetailView, AccountingDeleteView,
)
from .views import ReceiptListView, ReceiptCreateView, ReceiptTemplateSelectionView

model = {'model': Receipt}
fields = {
    'fields' : ['start', 'end', 'create_time', 'data']
}

app_name='receipts'
urlpatterns = [
    path(
        _('create/'),
        ReceiptCreateView.as_view(),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:pk>/details/'),
        AccountingDetailView.as_view(
            **model,
            **fields
        ),
        name='details'
    ),
    path(
        _('<int:pk>/delete/'),
        AccountingDeleteView.as_view(**model),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model
        ),
        name='delete_success'
    ),
    path(
        _('<int:pk>/receipt_download/'),
        ReceiptTemplateSelectionView.as_view(),
        name='receipt_download'
    ),
    path('', ReceiptListView.as_view(), name='default'),
]
