"""
A collection of forms used in this module.
"""

from django import forms
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _
from vkk.workhours.models import ProjectAssignment, WorkHours, WorkHoursCorrection


class ContributorDeleteForm(forms.ModelForm):
    """
    A `ModelForm` subclass for deleting a `ProjectAssignment`.
    """
    id = None
    class Meta:
        model = ProjectAssignment
        fields = []

    def __init__(self, id, *args, **kwargs):
        """
        Initializes and returns an object of this class. An `id` of a `ProjectAssignment` must be provided.
        """
        self.id = id
        super().__init__(*args, **kwargs)

    def clean(self):
        """
        Cleans the form and returns its cleaned data as an dictionary. No additional data must be associated
        with the given `ProjectAssignment` (ie. `WorkHours`) for this to be successfull.
        """
        workhours_exist = WorkHours.objects.filter(
            project_assignment__id=self.id
        ).exists()
        if workhours_exist:
            raise ValidationError(
                _('This project assignment cannot be deleted unless all associated workhours are deleted!'),
                code='workhours_exist'
            )
        corrections_exist = WorkHoursCorrection.objects.filter(
            project_assignment__id=self.id
        ).exists()
        if corrections_exist:
            raise ValidationError(
                _('This project assignment cannot be deleted unless all associated workhours corrections are deleted!'),
                code='corrections_exist'
            )
        return self.cleaned_data
