"""
This submodule contains the routing configuration.
"""

from django.urls import include, path
from django.utils.translation import gettext_lazy as _
from django.forms import modelform_factory
from vkk.workhours.accounting.views import *
from vkk.generic.forms import CustomDateInput
from vkk.workhours.models import Project

model = {'model': Project}
fields = {'fields': ['invoice_number', 'name', 'contractor', 'start', 'end']}
form_class = {'form_class': modelform_factory(
    **model,
    fields=['invoice_number', 'name', 'contractor',
            'department', 'start', 'end'],
    widgets={'start': CustomDateInput, 'end': CustomDateInput}
)}
action_options = {
    'action_options': {
        'project:default': _('Details'),
        'project:export:overview': _('Export'),
        'delete': _('Delete'),
    }
}
key = {'slug_field': 'invoice_number', 'slug_url_kwarg': 'invoice_number'}

app_name = 'projects'
urlpatterns = [
    path(
        _('create/'),
        AccountingCreateView.as_view(
            **model,
            **form_class,
        ),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:invoice_number>/delete/'),
        AccountingDeleteView.as_view(
            **model,
            **key,
            drop_key='invoice_number',
        ),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model,
        ),
        name='delete_success'
    ),
    path(
        '',
        AccountingFilterView.as_view(
            **model,
            **fields,
            **action_options,
            keys=key['slug_field'],
            ordering=['invoice_number'],
        ),
        name='default'
    ),
    path(_('<int:invoice_number>/project/'),
         include('vkk.workhours.accounting.projects.project.urls')),
]
