"""
This submodule contains the routing configuration.
"""

from django.urls import path
from django.utils.translation import gettext_lazy as _
from ..views import *
from .views import UserCreateView, AccountingUserDetailView
from vkk.users.models import User

model = {'model': User}
fields = {'fields': ['first_name', 'last_name', 'email', 'last_login']}
action_options = {'action_options' : {'details': _('Details'), 'update' : _('Update'), 'delete' : _('Delete')}}

app_name = 'users'
urlpatterns = [
    path(
        _('<int:pk>/details/'),
        AccountingUserDetailView.as_view(),
        name='details'
    ),
    path(
        _('create/'),
        UserCreateView.as_view(),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:pk>/update/'),
        AccountingUpdateView.as_view(**model, fields=['first_name', 'last_name', 'email', 'is_accountant', 'is_active']),
        name='update'
    ),
    path(
        _('update/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/update_success.html',
            **model
        ),
        name='update_success'
    ),
    path(
        _('<int:pk>/delete/'),
        AccountingDeleteView.as_view(**model),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model
        ),
        name='delete_success'
    ),
    path(
        '',
        AccountingFilterView.as_view(
            **model,
            **fields,
            **action_options,
            ordering=['last_name', 'first_name']
        ),
        name='default'
    ),
]