"""
This submodule contains the routing configuration.
"""

from django.urls import path
from django.utils.translation import gettext_lazy as _
from vkk.workhours.models import ProjectAssignment, PeriodClosure
from .views import (AllProjectAssigneesOverView, AssigneeUpdate,
                    AssigneeUpdateSuccessView, AllProjectYearRedirectView,
                    AssigneeClosureView, AssigneeClosureSuccessView)

app_name = 'allprojects'
urlpatterns = [
    path(
        '',
        AllProjectYearRedirectView.as_view(),
        name='default'
    ),
    path(
        _('year/<int:year>/'),
        AllProjectAssigneesOverView.as_view(),
        name='overview'
    ),
    path(
        _('year/<int:year>/assignee/<int:pk>/'),
        AssigneeUpdate.as_view(),
        name='update'
    ),
    path(
        _('year/<int:year>/assignee/success/'),
        AssigneeUpdateSuccessView.as_view(
            model=ProjectAssignment,
            template_name='vkk/generic/update_success.html',
            on_success='overview'
        ),
        name='update_success'
    ),
    path(
        _('year/<int:year>/assignee/<int:assignee_pk>/close/<int:period_pk>'),
        AssigneeClosureView.as_view(),
        name='closure'
    ),
    path(
        _('year/<int:year>/assignee/<int:assignee_pk>/close/success/'),
        AssigneeClosureSuccessView.as_view(
            model=PeriodClosure,
            template_name='vkk/generic/update_success.html',
            on_success='overview'
        ),
        name='closure_success'
    )
]
