"""
A collection of `Form`s for project managers.
"""

from django.forms import ModelForm, ModelChoiceField
from vkk.users.models import User
from vkk.workhours.models import SalaryLevel


class ProjectRegisterContributorForm(ModelForm):
    """
    A `ModelForm` subclass for registering new `User`s.
    """
    class Meta():
        """
        Meta information for the `ProjectRegisterContributorForm` class.
        """
        model = User
        fields = ['email', 'first_name', 'last_name']

    salary_level = ModelChoiceField(
        queryset=SalaryLevel.objects.all(),
        required=True
    )

    def save(self, commit=True):
        """
        Saves the associated `User` instance to the database and returns it.
        """
        self.instance.set_unusable_password()
        return super().save(commit)
