"""
This submodule contains a collection of mixin classes.
"""

from django.contrib.auth.mixins import AccessMixin
from django.utils import timezone
from ..models import Project, ProjectManager


class ManagerRequiredMixin(AccessMixin):
    """
    A mixin for verifying whether the current user is a manager of the given project.
    """
    check_field = None

    def dispatch(self, request, *args, **kwargs):
        """
        Overrides the `dispatch()` method of a class based view. If a user is not
         a manager of the given project, they are redirected.
        """
        project = Project.objects.filter(
            invoice_number=kwargs.get('invoice_number')
        )
        manager = ProjectManager.objects.filter(
            manager=request.user,
            project=project[0]
        )
        if (not request.user.is_authenticated or
            not project.exists() or
            not manager.exists() or
            manager[0].end < timezone.now().date()
            ):
            return self.handle_no_permission()
        if (self.check_field is not None and
                not self.model.objects.filter(
                    **{(self.check_field + '__invoice_number'): kwargs.get('invoice_number')}
                ).exists()):
            return self.handle_no_permission()
        return super().dispatch(request, *args, **kwargs)
