"""
This submodule contains the routing configuration.
"""

from django.urls import include, path
from django.utils.translation import gettext_lazy as _
from django.forms import modelform_factory
from vkk.workhours.models import ProjectManager, ProjectAssignment, Project, WorkHours
from vkk.generic.forms import CustomDateInput
from .views import *

app_name = 'manager'
urlpatterns = [
    path(
        _('<int:invoice_number>/details/'),
        ManagerProjectOverView.as_view(),
        name='default'
    ),
    path(
        _('<int:invoice_number>/update/success/'),
        ManagerSuccessView.as_view(
            model=Project,
            template_name='vkk/generic/update_success.html',
        ),
        name='update_success'
    ),
    path(
        _('<int:invoice_number>/manager/<int:pk>/details/'),
        ManagerDetailView.as_view(
            model=ProjectManager,
            template_name='vkk/workhours/manager/manager_details.html',
            check_field='project',
        ),
        name='manager_details'
    ),
    path(
        _('<int:invoice_number>/manager/<int:pk>/update/'),
        ManagerUpdateView.as_view(
            model=ProjectManager,
            form_class=modelform_factory(
                model=ProjectManager,
                fields=['start', 'end', 'is_proxy'],
                widgets={'start': CustomDateInput, 'end': CustomDateInput}
            ),
            on_success='manager_update_success',
            check_field='project',
        ),
        name='manager_update'
    ),
    path(
        _('<int:invoice_number>/manager/update/success/'),
        ManagerSuccessView.as_view(
            model=ProjectManager,
            template_name='vkk/generic/update_success.html',
            check_field='project',
        ),
        name='manager_update_success'
    ),
    path(
        _('<int:invoice_number>/contributor/<int:pk>/details/'),
        ManagerDetailView.as_view(
            model=ProjectAssignment,
            template_name='vkk/workhours/manager/contributor_details.html',
            check_field='project',
        ),
        name='contributor_details'
    ),
    path(
        _('<int:invoice_number>/contributor/<int:pk>/update/'),
        ManagerUpdateView.as_view(
            model=ProjectAssignment,
            form_class=modelform_factory(
                model=ProjectAssignment,
                fields=['salary_level'],
            ),
            on_success='contributor_update_success',
            check_field='project',
        ),
        name='contributor_update'
    ),
    path(
        _('<int:invoice_number>/contributor/update/success/'),
        ManagerSuccessView.as_view(
            model=ProjectManager,
            template_name='vkk/generic/update_success.html',
            check_field='project',
        ),
        name='contributor_update_success'
    ),
    path(
        _('<int:invoice_number>/contributor_candidates/'),
        ManagerContributorFilterView.as_view(
            template_name='vkk/workhours/manager/contributor_candidates.html',
            ordering=['last_name', 'first_name'],
        ),
        name='contributor_candidates'
    ),
    path(
        _('<int:invoice_number>/contributor_candidates/<int:pk>/add_new/'),
        ManagerContributorCreateView.as_view(),
        name='add_contributor'
    ),
    path(
        _('<int:invoice_number>/contributor_candidates/add_new/success/'),
        ManagerSuccessView.as_view(
            model=ProjectAssignment,
            template_name='vkk/generic/create_success.html',
            on_success='contributor_candidates'
        ),
        name='add_contributor_success'
    ),
    path(
        _('<int:invoice_number>/contributor_candidates/register_new/'),
        ManagerRegisterContributorView.as_view(),
        name='register_contributor'
    ),
    path(
        _('<int:invoice_number>/contributor_candidates/register_new/success/'),
        ManagerSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            model=User,
            on_success='contributor_candidates'
        ),
        name='register_contributor_success'
    ),
    # workhour sheet
    path(
        _('<int:invoice_number>/workhours_sheet/'),
        ManagerWorkhourSheetSelectionView.as_view(),
        name='workhours_sheet_selection'
    ),
    path(
        _('<int:invoice_number>/workhours_sheet/<int:period_pk>/'),
        ManagerWorkhourSheetView.as_view(),
        name='workhours_sheet'
    ),
    path(
        _('<int:invoice_number>/workhours_sheet/<int:period_pk>/success/'),
        ManagerSuccessView.as_view(
            template_name='vkk/workhours/workhours_sheet_success.html',
            model=WorkHours,
            on_success='workhours_sheet',
        ),
        name='workhours_sheet_success'
    ),
    path(
        _('<int:invoice_number>/workhours_sheet/<int:period_pk>/closure/'),
        ManagerPeriodClosureView.as_view(),
        name='period_closure'
    ),
    path(
        _('<int:invoice_number>/workhours_sheet/<int:period_pk>/closure/success/'),
        ManagerPeriodClosureSuccessView.as_view(),
        name='period_closure_success'
    ),
]
