"""
This submodule contains some Mixin classes.
"""

from django.urls import reverse
from vkk.workhours.models import Period
from vkk.workhours.forms import PeriodSelectForm


class PeriodSelectorMixin():
    """
    Adds a Form for selecting Periods to another Form-subclass.
    """

    period_select_namespace = None

    def get_context_data(self, **kwargs):
        """
        Adds the form for selecting `Period` instances to the context
        and returns it.
        """
        query_set = Period.objects.all()
        context = super().get_context_data(**kwargs)
        context['period_selector'] = PeriodSelectForm(
            queryset=query_set.order_by('-start'),
            initial={'period': self.kwargs['period_pk']}
        )
        return context

    def get_select_url(self):
        """
        Returns the URL for redirecting based on `period_select_namespace`.
        """
        return reverse(
            self.period_select_namespace,
            kwargs={'invoice_number': self.kwargs['invoice_number']}
        )
