from django.views.generic import TemplateView
"""
A submodule containing `View`s.
"""

from django.utils import timezone
from django.contrib.auth.mixins import LoginRequiredMixin


class OverView(LoginRequiredMixin, TemplateView):
    """
    Provides a `View` for a general overview page.
    """
    template_name = 'vkk/workhours/overview.html'

    def get_context_data(self, **kwargs):
        """
        Returns a dictionary with context data for the template layer.
        """
        context = super().get_context_data(**kwargs)
        context['assignments'] = self.request.user.projectassignment_set.only(
            'project'
        ).select_related('project')
        context['managed'] = self.request.user.projectmanager_set.only(
            'project'
        ).filter(
            end__gte=timezone.now().date()
        ).select_related('project').order_by('project__invoice_number')
        return context
