# Installation

Diese Installationsanleitung berücksichtigt zwei zwei Varianten: 
- Eine für die lokale Entwicklung (Manchmal auch kurz als "Dev" bezeichnet.)
- Eine für den Bertieb (Manchmal auch kurz als "Prod" bezeichnet.)

## Vorbereitung

Als Basis wird eine Installation von Ubuntu Linux 22.10 oder neuer vorrausgesetzt. Darüberhinaus werden `docker`, `docker-compose` und `git` benötigt:
```
sudo apt install docker docker-compose git
sudo systemctl enable docker
sudo systemctl start docker
```

Im nächsten Schritt wird die Git-Ablage des Projects kopiert:
```
git clone https://gitlab.informatik.uni-halle.de/acqgu/projektmedizin.git
cd projektmedizin/
```

Für die Entwicklung und Betrieb werden eine Reihe von Dateien mit Umgebungsvariablen benötigt. Diese müssen als nächstes erstellt werden. (Felder mit `****` müssen entsprechend ausgefüllt werden.)

`.env.dev` :
```
DEBUG=1
SECRET_KEY='****'
DJANGO_ALLOWED_HOSTS=localhost 127.0.0.1 [::1]
SQL_ENGINE=django.db.backends.postgresql
SQL_DATABASE=****
SQL_USER=****
SQL_PASSWORD=****
SQL_HOST=db
SQL_PORT=5432
DATABASE=postgres
```

`.env.prod` :
```
DEBUG=0
SECRET_KEY=****
DJANGO_ALLOWED_HOSTS=vkk.medizin.uni-halle.de
SQL_ENGINE=django.db.backends.postgresql
SQL_HOST=db
SQL_PORT=5432
DATABASE=postgres
```

`.env.prod.db` :
```
POSTGRES_USER=****
POSTGRES_PASSWORD=****
POSTGRES_DB=vkk_medizin
```

`.env.prod.dbuser` :
```
SQL_DATABASE=vkk_medizin
SQL_USER=****
SQL_PASSWORD=****
```

`.env.prod.mail` :
```
EMAIL_HOST=****
EMAIL_PORT=****
DEFAULT_FROM_EMAIL=****
EMAIL_HOST_USER=****
EMAIL_HOST_PASSWORD=****
```

Als Sicherheitsmaßnahme verläuft jede Kommunikation zwischen Container über TLS. Hierfür werden eine Reihe von selbstsignierten Zertifikate generiert. (Diese haben eine gültigkeit von 10 Jahre.) Die Passphrase sollte ausreichend lang sein.
```
export PASSPHRASE=****
bash ./generatelocalcerts.sh
```

Für den Betrieb müssen die Zertifikate für die Verschlüsselung der Webseite bereitgestellt werden: (Alternativ können auch Hardlinks erstellt werden.)
```
sudo cp /etc/certs/vkk.medizin.uni-halle.de.key ./nginx/ssl/vkk.medizin.uni-halle.de.key
sudo cp /etc/certs/vkk.medizin.uni-halle.de.pem ./nginx/ssl/vkk.medizin.uni-halle.de.crt
sudo cp /etc/certs/fullchain.pem ./nginx/ssl/fullchain.pem
```

## Erstellen der Container
Im nächsten Schritt werden die Docker-Container erstellt. 

Für die Entwicklung:
```
sudo docker-compose build --pull
```

Für den Betrieb:
```
sudo docker-compose -f docker-compose.prod.yml build --pull
```

## Einrichtung

Anschließend erfolgen ein paar Konfigurationsschritte.

### Frische Installation

Im Falle einer Installation, bei der keine Wiederherstellung der Datenbank erforderlicht ist, muss zunächst diese eingerichtet und ein Konto für die Verwaltung erstellt werden.

```
sudo docker-compose up -d
sudo docker-compose exec web /bin/ash
python manage.py migrate
python manage.py createsuperuser
```
Es folgt nun eine Reihe von Eingabeaufforderungen, um das Nutzer*innenkonto zu erstellen. Anschließen kann das Konto aktiviert und die Shell geschlossen werden:

```
python manage.py shell -c "from vkk.models import User; user = User.objects.all()[0]; user.is_active = True; user.save();"
exit
```

Analog für den Betrieb:
```
sudo docker-compose -f docker-compose.prod.yml up -d
sudo docker-compose exec web /bin/ash
python manage.py migrate
python manage.py createsuperuser
```
Es folgt nun eine Reihe von Eingabeaufforderungen, um das Nutzer*innenkonto zu erstellen. Anschließen kann das Konto aktiviert und die Shell geschlossen werden:

```
python manage.py shell -c "from vkk.models import User; user = User.objects.all()[0]; user.is_active = True; user.save();"
exit
```

### Wiederherstellung aus einem Backup

Sollte ein Backup der Datenbank vorliegen, kann dies zur Wiederherstellung genutzt werden. Entsprechende Datenbankdumps werden im Betrieb täglich vom Service `cron` erstellt und unter `/postgres/dump/` abgelegt.

Nach starten der Anwendung, muss der entsprechende Datenbankdump in den Container kopiert werden, bevor er mit `pg_restore` zur Wiederherstellung der Datenbank genutzt werden kann.

```
sudo docker-compose -f docker-compose.prod.yml up -d
sudo docker cp ./postgres/dumps/******.dump projektmedizin_db_1:/******.dump
sudo docker-compose exec db /bin/ash
pg_restore -c -C -d postgresql://$SQL_USER:$SQL_PASSWORD@/$SQL_DATABASE ******.dump
pg_restore -d postgresql://$SQL_USER:$SQL_PASSWORD@/$SQL_DATABASE ******.dump
exit
```

### Erstellen eines Systemd Service
Für einen automatischen Start des Servers mit dem Betriebssystem kann ein entsprechender Service für `systemd` eingerichtet und aktiviert werden.

Hierfür muss zuerst eine Beschreibung des Services erstellt werden. Hier ein Beispiel:

`vkk-docker-compose-app.service` :
```
# /etc/systemd/system/vkk-docker-compose-app.service

[Unit]
Description=VKK Docker Compose Application Service
Requires=docker.service
After=docker.service

[Service]
WorkingDirectory=********
ExecStart=docker-compose -f docker-compose.prod.yml up
ExecStop=docker-compose -f docker-compose.prod.yml down
TimeoutStartSec=0
Restart=on-failure
StartLimitIntervalSec=60
StartLimitBurst=3

[Install]
WantedBy=multi-user.target
```
Die entsprechende Datei wird danach kopiert und Service aktiviert und gestartet.

```
sudo cp vkk-docker-compose-app.service /etc/systemd/system/vkk-docker-compose-app.service
sudo systemctl enable vkk-docker-compose-app.service
sudo systemctl start vkk-docker-compose-app.service
```
Nach Neustart des Betriebssystem sollte die Anwendung ebenso automatisch bereit sein.